<?php
/**
 * @author Aqura
 * @since 1.0.0
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


class aqura__Meta_Boxes {

	protected static $instance = null;

	public $prefix = 'aqura_';

	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	protected function __construct() {

		add_action('rwmb_meta_boxes', array( &$this, 'aqura__register_meta_boxes'));

	}

	/**
	 * @param $meta_boxes
	 * @return array
	 */
	public function aqura__register_meta_boxes( $meta_boxes ) {
		$prefix = $this->prefix;

		$meta_boxes[] = array(
			'id'		=> "{$prefix}gallery_options",
			'title'  => esc_html__('Gallery Options', 'aqura'),
			'pages'  => array('gallery'),
			// 'context'   => 'side',
			'priority'  => 'high',
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Gallery Title', 'aqura' ),
					'id'			=> "{$prefix}gallery_title",
					'type'		  => 'text',
					'desc'		  => esc_html__( 'Use this field just if you want to make some words light.' , 'aqura' ),
				),
				array(
					'name'		  => esc_html__( 'Gallery Photos', 'aqura' ),
					'id'			=> "{$prefix}gallery_photos",
					'type'		  => 'image_advanced',
				),
				array(
					'name'		  => esc_html__( 'Gallery Thumbnail', 'aqura' ),
					'id'			=> "{$prefix}gallery_thumbnail",
					'type'		  => 'image_advanced',
					'max_file_uploads' => 1
				),
			),
		);

		$meta_boxes[] = array(
			'id'		=> "{$prefix}album_page_options",
			'title'  => esc_html__('Album Page Options', 'aqura'),
			'pages'  => array('albums'),
			// 'context'   => 'side',
			'priority'  => 'high',
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Page Background', 'aqura' ),
					'id'			=> "{$prefix}paage_bg",
					'type'		  => 'image_advanced',
					'max_file_uploads' => 1
				),
				array(
					'name'		  => esc_html__( 'Cover Album Image', 'aqura' ),
					'id'			=> "{$prefix}cover_album",
					'type'		  => 'image_advanced',
					'max_file_uploads' => 1
				),
				array(
					'name'		  => esc_html__( 'Disk Image', 'aqura' ),
					'id'			=> "{$prefix}disk_image",
					'type'		  => 'image_advanced',
					'max_file_uploads' => 1
				)
			),
		);

		$meta_boxes[] = array(
			'id'		=> "{$prefix}album_details",
			'title'  => esc_html__('Album Details', 'aqura'),
			'pages'  => array('albums'),
			// 'context'   => 'side',
			'priority'  => 'high',
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Release date', 'aqura' ),
					'id'			=> "{$prefix}release_date",
					'type'		  => 'text',
				),
				array(
					'name'		  => esc_html__( 'Catalog', 'aqura' ),
					'id'			=> "{$prefix}album_catalog",
					'type'		  => 'text'
				),
				array(
					'name'		  => esc_html__( 'Label', 'aqura' ),
					'id'			=> "{$prefix}album_label",
					'type'		  => 'text'
				),
				array(
					'name'		  => esc_html__( 'Format', 'aqura' ),
					'id'			=> "{$prefix}album_format",
					'type'		  => 'text'
				)
			),
		);

		$meta_boxes[] = array(
			'id'		=> "{$prefix}album_download",
			'title'  => esc_html__('Album Download Links', 'aqura'),
			'pages'  => array('albums'),
			// 'context'   => 'side',
			'priority'  => 'high',
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Last.fm', 'aqura' ),
					'id'			=> "{$prefix}last_fm",
					'type'		  => 'text',
				),
				array(
					'name'		  => esc_html__( 'SoundCloud', 'aqura' ),
					'id'			=> "{$prefix}album_soundcloud",
					'type'		  => 'text'
				),
				array(
					'name'		  => esc_html__( 'iTunes', 'aqura' ),
					'id'			=> "{$prefix}album_itunes",
					'type'		  => 'text'
				),
				array(
					'name'		  => esc_html__( 'Spotify', 'aqura' ),
					'id'			=> "{$prefix}spotify",
					'type'		  => 'text'
				),
				array(
					'name'		  => esc_html__( 'Amazon', 'aqura' ),
					'id'			=> "{$prefix}amazon",
					'type'		  => 'text'
				),
				array(
					'name'		  => esc_html__( 'Beatport', 'aqura' ),
					'id'			=> "{$prefix}beatport",
					'type'		  => 'text'
				)
			),
		);

		$meta_boxes[] = array(
			'title'  => esc_html__( 'Album Tracks', 'aqura' ),
			'post_types' => array( 'albums' ),
			'fields' => array(
				array(
					'id'	 => 'album-tracks',
					'type'   => 'group',
					'clone'  => true,
					'sort_clone' => true,
					'fields' => array(
						array(
							'name' => esc_html__( 'Track name', 'aqura' ),
							'id'   => 'track-name',
							'type' => 'text'
						),
						array(
							'name' => esc_html__( 'Track author', 'aqura' ),
							'id'   => 'track-author',
							'type' => 'text'
						),
						array(
							'name' => esc_html__( 'Song Thumbnail', 'aqura' ),
							'id'   => "track-thumbnail",
							'type' => 'file_advanced',
							'desc' => esc_html__('30px X 30px.', 'aqura' ),
							'max_file_uploads' => 1
						),
						array(
							'name' => esc_html__( 'Song Upload', 'aqura' ),
							'id'   => "track-url",
							'type' => 'file_advanced',
							'mime_type' => 'application,audio,video', // Leave blank for all file types
							'desc' => esc_html__('The file you wish to upload (.mp3 format preferably).', 'aqura' ),
							'max_file_uploads' => 1
						),
						array(
							'name'  => esc_html__( 'Song External URL / Radio Stream URL', 'aqura' ),
							'id'	=> "track-external-url",
							'desc'  => __( 'If you write some URL into this box, it will <strong>override</strong> the above upload form. So if you have an uploaded song and an url here, the URL will be used. Also here you can add the soundcloud url to play tracks from SoundCloud.', 'aqura' ),
							'type'  => 'text',
						),
						array(
							'name' => esc_html__( 'Track Duration', 'aqura' ),
							'id'   => 'track-duration',
							'type' => 'text',
							'desc'  => esc_html__( 'If you use an External URL for this track, the duration won\'t show in players if you don\'t add it here.', 'aqura' ),
							'hidden' => array( 'track-external-url', '=', '' )
						),
					),
				),
			),
		);

		$meta_boxes[] = array(
			'id'		=> "{$prefix}post_options_post",
			'title'  => esc_html__('Post Options', 'aqura'),
			'pages'  => array('post'),
			// 'context'   => 'side',
			'priority'  => 'high',
			'tabs'	  => array(
				'top_section_tab'	  => esc_html__( 'Top Section', 'aqura' ),
				'article_type_tab'	  => esc_html__( 'Article Type', 'aqura' ),
			),
			'tab_style' => 'left',
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Title', 'aqura' ),
					'id'			=> "{$prefix}single_article_title",
					'type'		  => 'text',
					'tab'  => 'top_section_tab',
					'desc'		  => esc_html__( 'If this field is empty the title will be the article title.', 'aqura' ),
				),
				array(
					'name'		  => esc_html__( 'Small Description', 'aqura' ),
					'id'			=> "{$prefix}small_description",
					'type'		  => 'textarea',
					'tab'  => 'top_section_tab',
				),
				array(
					'name'		  => esc_html__( 'View More Text', 'aqura' ),
					'id'			=> "{$prefix}view_more_text",
					'type'		  => 'text',
					'desc'		  => esc_html__( 'If this field is empty the view more text will be "View More".', 'aqura' ),
					'tab'  => 'top_section_tab',
				),
				array(
					'name'		  => esc_html__( 'Choose the type of this article', 'aqura' ),
					'id'			=> "{$prefix}article_type",
					'type'		  => 'radio',
					'tab'  => 'article_type_tab',
					'options'	   => array(
						'vimeo'		 	=> esc_html__('Vimeo', 'aqura'),
						'youtube'		=> esc_html__('YouTube', 'aqura'),
						'gallery'		=> esc_html__('Gallery', 'aqura'),
						'soundcloud'	=> esc_html__('Soundcloud', 'aqura')
					)
				),
				array(
					'name'		  => esc_html__( 'Video ID', 'aqura' ),
					'id'			=> "{$prefix}video_id",
					'type'		  => 'text',
					'tab'  => 'article_type_tab',
				),
				array(
					'name'		  => esc_html__( 'Soundcloud Track ID', 'aqura' ),
					'id'			=> "{$prefix}soundcloud_id",
					'type'		  => 'text',
					'tab'  => 'article_type_tab',
				),
				array(
					'name' => esc_html__( 'Gallery Images', 'aqura' ),
					'id'   => 'aqura_gallery_images_post',
					'type' => 'image_advanced',
					'tab'  => 'article_type_tab',
				),
			),
		);

		$meta_boxes[] = array(
			'id'		=> "{$prefix}page_options",
			'title'  => esc_html__('Page Options', 'aqura'),
			'pages'  => array('page'),
			// 'context'   => 'side',
			'priority'  => 'high',
			'show'   => array(
				'relation'	=> 'OR',
				'template'	=> array( 'template-parts/template-gallery-grid.php' , 'template-parts/page.php' , 'template-parts/template-blog.php' , 'template-parts/template-blog-grid.php' , 'template-parts/template-contact.php' , 'template-parts/template-empty.php' , 'template-parts/template-full-width-empty.php' ),
			),
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Title', 'aqura' ),
					'id'			=> "{$prefix}single_article_title",
					'type'		  => 'text',
					'desc'		  => esc_html__( 'If this field is empty the title will be the article title.', 'aqura' ),
				),
				array(
					'name'		  => esc_html__( 'Small Description', 'aqura' ),
					'id'			=> "{$prefix}small_description",
					'type'		  => 'textarea',
				),
				array(
					'name'		  => esc_html__( 'View More Text', 'aqura' ),
					'id'			=> "{$prefix}view_more_text",
					'type'		  => 'text',
					'desc'		  => esc_html__( 'If this field is empty the view more text will be "View More".', 'aqura' )
				),
			),
		);

		$meta_boxes[] = array(
			'id'		=> "{$prefix}page_options_contact",
			'title'  => esc_html__('Contact Options', 'aqura'),
			'pages'  => array('page'),
			'show'   => array(
				'relation'	=> 'OR',
				'template'	=> array( 'template-parts/template-contact.php' ),
			),
			// 'context'   => 'side',
			'priority'  => 'high',
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Contact Form Title', 'aqura' ),
					'id'			=> "{$prefix}contact_title",
					'type'		  => 'text',
					'desc'		  => esc_html__( 'By default is "Get in Touch".', 'aqura' ),
				),
				array(
					'name'		  => esc_html__( 'Page Background', 'aqura' ),
					'id'			=> "{$prefix}contact_background",
					'type'		  => 'image_advanced',
					'max_file_uploads' => 1
				),
				array(
					'name'		  => esc_html__( 'Contact Form ID', 'aqura' ),
					'id'			=> "{$prefix}contact_form_id",
					'type'		  => 'text'
				),
			),
		);

		$meta_boxes[] = array(
			'id'		=> "{$prefix}page_options_post",
			'title'  => esc_html__('Page Options', 'aqura'),
			'pages'  => array('page'),
			'show'   => array(
				'relation'	=> 'OR',
				'template'	=> array( 'template-parts/template-blog.php' , 'template-parts/template-blog-grid.php' ),
			),
			// 'context'   => 'side',
			'priority'  => 'high',
			'fields'	 => array(
				array(
					'name'		  => esc_html__( 'Posts per Page', 'aqura' ),
					'id'			=> "{$prefix}posts_per_page",
					'type'		  => 'number',
					'desc'		  => esc_html__( 'By default is 5.', 'aqura' ),
				),
			),
		);

		return $meta_boxes;
	}
	
	public function aqura_save_meta_box_data( $post_id ) {
		
		
		// If this is an autosave, our form has not been submitted, so we don't want to do anything.
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		
		// Check the user's permissions.
		if ( ! current_user_can( 'edit_themes', $post_id ) ) {
			return;
		}

	}

}

aqura__Meta_Boxes::get_instance();