<?php
/**
 * @author Aqura
 * @since 1.0.0
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }

if( ! function_exists( 'aqura_the_excerpt' ) ) :
	function aqura_the_excerpt() {
		echo aqura_get_the_excerpt();
	}
endif;

if(!class_exists('RWMB_Helper')) {

    function rwmb_meta( $key, $aqura_args = array(), $post_id = null )
    {
        $post_id = empty( $post_id ) ? get_the_ID() : $post_id;
        $aqura_args    = wp_parse_args( $aqura_args, array(
            'type'     => 'text',
            'multiple' => false,
        ) );

        // Always set 'multiple' true for following field types
        if ( in_array( $aqura_args['type'], array( 'checkbox_list', 'file', 'file_advanced', 'image', 'image_advanced', 'plupload_image', 'thickbox_image' ) ) )
        {
            $aqura_args['multiple'] = true;
        }

        $meta = get_post_meta( $post_id, $key, ! $aqura_args['multiple'] );

        // Get uploaded files info
        if ( in_array( $aqura_args['type'], array( 'file', 'file_advanced' ) ) )
        {
            if ( is_array( $meta ) && ! empty( $meta ) )
            {
                $files = array();
                foreach ( $meta as $id )
                {
                    // Get only info of existing attachments
                    if ( get_attached_file( $id ) )
                    {
                        $files[$id] = RWMB_File_Field::file_info( $id );
                    }
                }
                $meta = $files;
            }
        }
        // Get uploaded images info
        elseif ( in_array( $aqura_args['type'], array( 'image', 'plupload_image', 'thickbox_image', 'image_advanced' ) ) )
        {
            if ( is_array( $meta ) && ! empty( $meta ) )
            {
                $images = array();
                foreach ( $meta as $id )
                {
                    // Get only info of existing attachments
                    if ( get_attached_file( $id ) )
                    {
                        $images[$id] = RWMB_Image_Field::file_info( $id, $aqura_args );
                    }
                }
                $meta = $images;
            }
        }
        // Get terms
        elseif ( 'taxonomy_advanced' == $aqura_args['type'] )
        {
            if ( ! empty( $aqura_args['taxonomy'] ) )
            {
                $term_ids = array_map( 'intval', array_filter( explode( ',', $meta . ',' ) ) );
                // Allow to pass more arguments to "get_terms"
                $func_args = wp_parse_args( array(
                    'include'    => $term_ids,
                    'hide_empty' => false,
                ), $aqura_args );
                unset( $func_args['type'], $func_args['taxonomy'], $func_args['multiple'] );
                $meta = get_terms( $aqura_args['taxonomy'], $func_args );
            }
            else
            {
                $meta = array();
            }
        }
        // Get post terms
        elseif ( 'taxonomy' == $aqura_args['type'] )
        {
            $meta = empty( $aqura_args['taxonomy'] ) ? array() : wp_get_post_terms( $post_id, $aqura_args['taxonomy'] );
        }
        // Get map
        elseif ( 'map' == $aqura_args['type'] )
        {
            $field = array(
                'id'       => $key,
                'multiple' => false,
                'clone'    => false,
            );
            $meta  = RWMB_Map_Field::the_value( $field, $aqura_args, $post_id );
        }
        // Display oembed content
        elseif ( 'oembed' == $aqura_args['type'] )
        {
            $field = array(
                'id'       => $key,
                'clone'    => isset( $aqura_args['clone'] ) ? $aqura_args['clone'] : false,
                'multiple' => isset( $aqura_args['multiple'] ) ? $aqura_args['multiple'] : false,
            );
            $meta  = RWMB_OEmbed_Field::the_value( $field, $aqura_args, $post_id );
        }
        return apply_filters( 'rwmb_meta', $meta, $key, $aqura_args, $post_id );
    }

}

if( ! function_exists( 'aqura_get_the_excerpt' ) ) :

	/**
	* Returns a nice excerpt/content for the blog page.
	*
	* @return mixed|string|void
	*
	* @since 1.0.0
	*
	*/

	function aqura_get_the_excerpt() {

		global $post, $more, $pages;
		$more = 0;

		if ( !has_excerpt( $post->ID ) ) {

			$excerpt_length = apply_filters('excerpt_length', 55);
			$content = aqura_get_the_clear_content();

			// check for more tag
			if ( preg_match( '/<!--more(.*?)?-->/', $post->post_content, $matches ) ) {

				// check content length
			} elseif ( aqura_count_words( $content ) <= $excerpt_length ) {

				add_filter('aqura_get_content_more', 'aqura_return_empty_string', 15);

			} else {

				$content = '';

			}

		}

		// if we got excerpt or content more than $excerpt_length
		if ( empty($content) && get_the_excerpt() ) {

			$content = apply_filters( 'the_excerpt', get_the_excerpt() );

		}

		return $content;

	}
endif;

if( ! function_exists( 'aqura_return_empty_string' ) ) :
	/**
	* Return empty string.
	*
	* @return string
	*/
	function aqura_return_empty_string() {
		return '';
	}
endif;

if( ! function_exists( 'aqura_get_content_more' ) ) :

	/**
	* A filter for the "Read More" button
	*
	* @return mixed|void
	*
	* @since 1.0.0
	*/

	function aqura_get_content_more() {
		$more_button = '<a href="';
		$more_button .= get_permalink();
		$more_button .= '" >';
		$more_button .= esc_html__('read more', 'aqura');
		$more_button .= ' <i class="fa fa-arrow-right"></i></a>';

		return apply_filters('aqura_get_content_more', $more_button);
	}

endif;

if( ! function_exists( 'aqura_post_single_nav' ) ) :

	function aqura_post_single_nav($current_id, $post_type) {

		$aqura_args = array(
			'posts_per_page'   => 999,
			'offset'		=> 0,
			'category'	=> '',
			'orderby'	  => 'post_date',
			'order'   => 'DESC',
			'include'	  => '',
			'exclude'	  => '',
			'meta_key'	=> '',
			'meta_value'	 => '',
			'post_type'  => $post_type,
			'post_mime_type'   => '',
			'post_parent'	=> '',
			'post_status'	=> 'publish',
			'suppress_filters' => true );

		$posts_array = get_posts( $aqura_args );

		$n = count($posts_array);
		$has_next = false;
		$has_previous = false;
		$next_portfolio = array();
		$previous_portfolio = array();

		for ( $i = 0; $i < $n; $i++ ){
			if ( $current_id == $posts_array[$i]->ID && $n > 1 ) {

				if( $i == 0 ) {
					$has_next = false;
					$has_previous = true;

					$next_portfolio = array();
					$previous_portfolio = array('id' => $posts_array[$i+1]->ID,'author' => $posts_array[$i+1]->post_author,'title' => $posts_array[$i+1]->post_title, 'link' => get_permalink( $posts_array[$i+1]->ID ));
				} else if( $i == $n-1 ) {
					$has_next = true;
					$has_previous = false;

					$next_portfolio = array('id' => $posts_array[$i-1]->ID,'author' => $posts_array[$i-1]->post_author,'title' => $posts_array[$i-1]->post_title, 'link' => get_permalink( $posts_array[$i-1]->ID ));
					$previous_portfolio = array();
				} else {
					$has_next = true;
					$has_previous = true;

					$next_portfolio = array('id' => $posts_array[$i-1]->ID,'author' => $posts_array[$i-1]->post_author,'title' => $posts_array[$i-1]->post_title, 'link' => get_permalink( $posts_array[$i-1]->ID ));
					$previous_portfolio = array('id' => $posts_array[$i+1]->ID,'author' => $posts_array[$i+1]->post_author,'title' => $posts_array[$i+1]->post_title, 'link' => get_permalink( $posts_array[$i+1]->ID ));
				}

			}
		}

		?>

		<div class="col-sm-6">
		<?php if ($has_previous) : ?>
			<a href="<?php echo esc_url($previous_portfolio['link']); ?>" class="pagination-previous">
				<small>
					<?php esc_html_e( 'Previous Post' , 'aqura' ) ?>
				</small>
			</a>
		<?php else: ?>
			<a class="pagination-previous end">
				<small>
					<?php esc_html_e( 'Previous Post' , 'aqura' ) ?>
				</small>
			</a>
		<?php endif; ?>
		</div>

		<div class="col-sm-6">
		<?php if ($has_next) : ?>
			<a href="<?php echo esc_url($next_portfolio['link']); ?>" class="pagination-next">
				<small>
					<?php esc_html_e( 'Next Post' , 'aqura' ) ?>
				</small>
			</a>
		<?php else: ?>
			<a class="pagination-next end">
				<small>
					<?php esc_html_e( 'Next Post' , 'aqura' ) ?>
				</small>
			</a>
		<?php endif; ?>
		</div>

	<?php

	}

endif;

if(!function_exists('aqura_breadcrumbs_filter')) :

	function aqura_breadcrumbs_filter($taxonomy, $ids = array()) {
		$aqura_output = '';

		$aqura_output .= '<nav><div class="x-filter"><span></span><span></span></div><ul data-option-key="filter" class="option-set">';
		$aqura_output .= '<li><a class="selected" data-option-value="*">'.__('All', 'aqura').'</a></li>';

		if(empty($ids)) {
			$terms = get_terms($taxonomy);

			foreach($terms as $term) { $ids[] = $term->term_id; }
		}

		foreach($ids as $id) {
			$term = get_term($id, $taxonomy);

			$aqura_output .= '<li><a data-option-value=".'.$term->slug.'">'.$term->name.'</a></li>';
		}

		$aqura_output .= '</ul><div class="x-filter">
					<span></span>
					<span></span>
				</div></nav>';


		return $aqura_output;
	}

endif;

if( !function_exists('aqura_get_google_maps') ) :

	function aqura_get_google_maps($address, $visible = true) {

		$coordinates = aqura_get_coordinates($address);

		global $aqura_data;
		$pointer = $aqura_data['map-image']['url'];
		$aqura_title = $aqura_data['contact-title'];
		$description = $aqura_data['contact-description'];

		if($visible) {
			$aqura_output = '<div id="map-canvas" class="google-map" data-lat="'.$coordinates['lat'].'" data-long="'.$coordinates['lng'].'" data-img="'.$pointer.'" data-title="'.$aqura_title.'" data-description="'.$description.'"></div>';

			return $aqura_output;
		} else {return '';}

	}

endif;

if( !function_exists('aqura_get_coordinates') ) :

	/**
	* @param $address
	* @param bool $force_refresh
	* @return array|mixed|string|void
	*/
	function aqura_get_coordinates($address, $force_refresh = false) {
		$address_hash = md5( $address );

		$coordinates = get_transient( $address_hash );

		if ($force_refresh || $coordinates === false) {

			$aqura_args	= array( 'address' => urlencode( $address ), 'sensor' => 'false' );
			$url	  = add_query_arg( $aqura_args, 'http://maps.googleapis.com/maps/api/geocode/json' );
			$response   = wp_remote_get( $url );

			if( is_wp_error( $response ) )
				return;

			$data = wp_remote_retrieve_body( $response );

			if( is_wp_error( $data ) )
				return;

			if ( $response['response']['code'] == 200 ) {

				$data = json_decode( $data );

				if ( $data->status === 'OK' ) {

					$coordinates = $data->results[0]->geometry->location;

					$cache_value['lat']   = $coordinates->lat;
					$cache_value['lng']   = $coordinates->lng;
					$cache_value['address'] = (string) $data->results[0]->formatted_address;

					// cache coordinates for 3 months
					set_transient($address_hash, $cache_value, 3600*24*30*3);
					$data = $cache_value;

				} elseif ( $data->status === 'ZERO_RESULTS' ) {
					return esc_html__( 'No location found for the entered address.', 'aqura' );
				} elseif( $data->status === 'INVALID_REQUEST' ) {
					return esc_html__( 'Invalid request. Did you enter an address?', 'aqura' );
				} else {
					return esc_html__( 'Something went wrong while retrieving your map, please ensure you have entered the short code correctly.', 'aqura' );
				}

			} else {
				return esc_html__( 'Unable to contact Google API service.', 'aqura' );
			}

		} else {
			// return cached results
			$data = $coordinates;
		}

		return $data;
	}

endif;

if ( !function_exists('aqura_max_string_len') ) :
	
	function aqura_max_string_len($aqura_title_article = '',$before = '', $after = '', $echo = true, $length = false) {

		$aqura_title = $aqura_title_article;

		if ( $length && is_numeric($length) ) {
			$aqura_title = substr( $aqura_title, 0, $length );
		}

		if ( strlen($aqura_title) > 0 ) {
			if (strlen($aqura_title) == intval($length) ) {
				$aqura_title = apply_filters('aqura_max_string_len', $before . $aqura_title . $after, $before, $after);
			} else {
				$aqura_title = apply_filters('aqura_max_string_len', $before . $aqura_title . $before, $after);
			}
			if ( $echo )
				echo esc_html($aqura_title);
			else
				return $aqura_title;
		}
	}

endif;

if( !function_exists('aqura_breadcrumbs') ) :

	// aqura breadcrumb func

	function aqura_breadcrumbs() {

		// Settings
		$aqura_separator	 = '&gt;';
		$breadcrums_id	= 'breadcrumbs';
		$breadcrums_class   = 'breadcrumb';
		$home_title   = 'Homepage';

		// If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
		$custom_taxonomy	= 'product_cat';

		// Get the query & post information
		global $post,$wp_query;

		// Do not display on the homepage
		if ( !is_home() && !is_front_page() ) {

			// Build the breadcrums
			echo '<ol id="' . $breadcrums_id . '" class="' . $breadcrums_class . '">';

			// Home page
			echo '<li class="item-home"><a class="bread-link bread-home" href="' . get_home_url() . ' " title="' . $home_title . '">' . $home_title . ' </a></li>';

			if ( is_archive() && !is_tax() && !is_category() && !is_tag() ) {

				if ( post_type_archive_title() ) :
					echo '<li class="active item-archive">' . post_type_archive_title($prefix, false) . '</li>';
				else :
					echo '<li class="active item-archive">' . get_the_archive_title() . '</li>';
				endif;

			} else if ( is_archive() && is_tax() && !is_category() && !is_tag() ) {

				// If post is a custom post type
				$post_type = get_post_type();

				// If it is a custom post type display name and link
				if($post_type != 'post') {

					$post_type_object = get_post_type_object($post_type);
					$post_type_archive = get_post_type_archive_link($post_type);

					echo '<li class="item-cat item-custom-post-type-' . $post_type . '"><a class="bread-cat bread-custom-post-type-' . $post_type . '" href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . ' </a></li>';

				}

				$custom_tax_name = get_queried_object()->name;
				echo '<li class="active item-archive">' . $custom_tax_name . '</li>';

			} else if ( is_single() ) {

				// If post is a custom post type
				$post_type = get_post_type();

				// If it is a custom post type display name and link
				if($post_type != 'post') {

					$post_type_object = get_post_type_object($post_type);
					$post_type_archive = get_post_type_archive_link($post_type);

					echo '<li class="item-cat item-custom-post-type-' . $post_type . '"><a class="bread-cat bread-custom-post-type-' . $post_type . '" href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . ' </a></li>';


				}

				// Get post category info
				$category = get_the_category();

				if(!empty($category)) {

					// Get last category post is in
					$last_category = end($category);

					// Get parent any categories and create array
					$get_cat_parents = rtrim(get_category_parents($last_category->term_id, true, ','),',');
					$cat_parents = explode(',',$get_cat_parents);

					// Loop through parent categories and store in variable $cat_display
					$cat_display = '';
					foreach($cat_parents as $parents) {
						$cat_display .= '<li class="item-cat">'.$parents.'</li>';
					}

				}

				// If it's a custom post type within a custom taxonomy
				$taxonomy_exists = taxonomy_exists($custom_taxonomy);
				if(empty($last_category) && !empty($custom_taxonomy) && $taxonomy_exists) {

					$taxonomy_terms = get_the_terms( $post->ID, $custom_taxonomy );
					$cat_id   = $taxonomy_terms[0]->term_id;
					$cat_nicename   = $taxonomy_terms[0]->slug;
					$cat_link	 = get_term_link($taxonomy_terms[0]->term_id, $custom_taxonomy);
					$cat_name	 = $taxonomy_terms[0]->name;

				}

				// Check if the post is in a category
				if(!empty($last_category)) {
					echo balanceTags($cat_display);
					echo '<li class="active item-' . $post->ID . '">' . get_the_title() . '</li>';

					// Else if post is in a custom taxonomy
				} else if(!empty($cat_id)) {

					echo '<li class="item-cat item-cat-' . $cat_id . ' item-cat-' . $cat_nicename . '"><a class="bread-cat bread-cat-' . $cat_id . ' bread-cat-' . $cat_nicename . '" href="' . $cat_link . '" title="' . $cat_name . '">' . $cat_name . ' </a></li>';

					echo '<li class="active item-' . $post->ID . '">' . get_the_title() . '</li>';

				} else {

					echo '<li class="active item-' . $post->ID . '">' . get_the_title() . '</li>';

				}

			} else if ( is_category() ) {

				// Category page
				echo '<li class="active item-cat"><strong class="bread-current bread-cat">' . single_cat_title('', false) . '</strong></li>';

			} else if ( is_page() ) {

				// Standard page
				if( $post->post_parent ){

					// If child page, get parents
					$anc = get_post_ancestors( $post->ID );

					// Get parents in the right order
					$anc = array_reverse($anc);

					// Parent page loop
					foreach ( $anc as $ancestor ) {
						$parents .= '<li class="item-parent item-parent-' . $ancestor . '"><a class="bread-parent bread-parent-' . $ancestor . '" href="' . get_permalink($ancestor) . '" title="' . get_the_title($ancestor) . '">' . get_the_title($ancestor) . ' </a></li>';

					}

					// Display parent pages
					echo balanceTags($parents);

					// Current page
					echo '<li class="active item-' . $post->ID . '"><strong title="' . get_the_title() . '"> ' . get_the_title() . '</strong></li>';

				} else {

					// Just display current page if not parents
					echo '<li class="active item-' . $post->ID . '"><strong class="bread-current bread-' . $post->ID . '"> ' . get_the_title() . '</strong></li>';

				}

			} else if ( is_tag() ) {

				// Tag page

				// Get tag information
				$term_id		= get_query_var('tag_id');
				$taxonomy	 = 'post_tag';
				$aqura_args		= 'include=' . $term_id;
				$terms	 = get_terms( $taxonomy, $aqura_args );
				$get_term_id	= $terms[0]->term_id;
				$get_term_slug  = $terms[0]->slug;
				$get_term_name  = $terms[0]->name;

				// Display the tag name
				echo '<li class="active item-tag-' . $get_term_id . ' item-tag-' . $get_term_slug . '"><strong class="bread-current bread-tag-' . $get_term_id . ' bread-tag-' . $get_term_slug . '">' . $get_term_name . '</strong></li>';

			} elseif ( is_day() ) {

				// Day archive

				// Year link
				echo '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link( get_the_time('Y') ) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . ' Archives</a></li>';


				// Month link
				echo '<li class="item-month item-month-' . get_the_time('m') . '"><a class="bread-month bread-month-' . get_the_time('m') . '" href="' . get_month_link( get_the_time('Y'), get_the_time('m') ) . '" title="' . get_the_time('M') . '">' . get_the_time('M') . ' Archives</a></li>';


				// Day display
				echo '<li class="active item-' . get_the_time('j') . '"><strong class="bread-current bread-' . get_the_time('j') . '"> ' . get_the_time('jS') . ' ' . get_the_time('M') . ' Archives</strong></li>';

			} else if ( is_month() ) {

				// Month Archive

				// Year link
				echo '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link( get_the_time('Y') ) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . ' Archives</a></li>';


				// Month display
				echo '<li class="item-month item-month-' . get_the_time('m') . '"><strong class="bread-month bread-month-' . get_the_time('m') . '" title="' . get_the_time('M') . '">' . get_the_time('M') . ' Archives</strong></li>';

			} else if ( is_year() ) {

				// Display year archive
				echo '<li class="active active-' . get_the_time('Y') . '"><strong class="bread-current bread-current-' . get_the_time('Y') . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . ' Archives</strong></li>';

			} else if ( is_author() ) {

				// Auhor archive

				// Get the author information
				global $author;
				$userdata = get_userdata( $author );

				// Display author name
				echo '<li class="active active-' . $userdata->user_nicename . '"><strong class="bread-current bread-current-' . $userdata->user_nicename . '" title="' . $userdata->display_name . '">' . 'Author: ' . $userdata->display_name . '</strong></li>';

			} else if ( get_query_var('paged') ) {

				// Paginated archives
				echo '<li class="active active-' . get_query_var('paged') . '"><strong class="bread-current bread-current-' . get_query_var('paged') . '" title="Page ' . get_query_var('paged') . '">'.__('Page','aqura') . ' ' . get_query_var('paged') . '</strong></li>';

			} else if ( is_search() ) {

				// Search results page
				echo '<li class="active active-' . get_search_query() . '"><strong class="bread-current bread-current-' . get_search_query() . '" title="Search results for: ' . get_search_query() . '">Search results for: ' . get_search_query() . '</strong></li>';

			} elseif ( is_404() ) {

				// 404 page
				echo '<li>' . 'Error 404' . '</li>';
			}

			echo '</ol>';

		} elseif ( is_home() && !is_front_page() ) {
				
			// Build the breadcrums
			echo '<ol id="' . $breadcrums_id . '" class="' . $breadcrums_class . '">';

			// Home page
			echo '<li class="item-home"><a class="bread-link bread-home" href="' . get_home_url() . ' " title="' . $home_title . '">' . $home_title . ' </a></li>';

			// Just display current page if not parents
			echo '<li class="active item-' . $post->ID . '"><strong class="bread-current bread-' . $post->ID . '"> ' . apply_filters('the_title',get_page( get_option('page_for_posts') )->post_title) . '</strong></li>';

			echo '</ol>';

		}

	}

endif;

if( !function_exists('aqura_comment') ) :

	// Comments Template

	function aqura_comment($comment, $aqura_args, $depth) {
		$GLOBALS['comment'] = $comment;
		extract($aqura_args, EXTR_SKIP);

		if ( 'div' == $aqura_args['style'] ) {
			$tag = 'div';
			$add_below = 'comment';
		} else {
			$tag = 'li';
			$add_below = 'div-comment';
		}
		?>
		<<?php echo esc_attr($tag) ?> <?php comment_class( empty( $aqura_args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
		<?php if ( 'div' != $aqura_args['style'] ) : ?>
			<div id="div-comment-<?php comment_ID() ?>" class="comment">
		<?php endif; ?>
		<div class="left-section">
			<?php if ( $aqura_args['avatar_size'] != 0 ) echo get_avatar( $comment, 40 ); ?>
		</div>
		<div class="right-section">
			<h3>
				<?php printf( esc_html__( '%s' , 'aqura' ), get_comment_author_link() ); ?>
			</h3>
			<p class="time-comment">
				<?php
				printf( esc_html__('%1$s','aqura'), get_comment_date('d M Y') ); ?></a><?php edit_comment_link( esc_html__( '(Edit)' , 'aqura' ), '  ', '' );
				?>
				<?php if ( $depth == 1 || $depth == 2 ): ?>
					<span class="slashComment">/</span>
				<?php endif ?>
				<?php comment_reply_link( array_merge( $aqura_args, array( 'add_below' => $add_below , 'reply_text' => esc_html__('Reply ', 'aqura') . '', 'depth' => $depth, 'max_depth' => $aqura_args['max_depth'] ) ) ); ?>
			</p>
			<div class="comment-text">
				<?php comment_text(); ?>
			</div>
		</div>
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'aqura' ); ?></em>
			<br />
		<?php endif; ?>
		<?php if ( 'div' != $aqura_args['style'] ) : ?>
			</div>
		<?php endif; ?>
	<?php }

endif;

if( !function_exists('aqura_comment_ping') ) :

	// Comments Template

	function aqura_comment_ping($comment, $aqura_args, $depth) {
		$GLOBALS['comment'] = $comment;
		extract($aqura_args, EXTR_SKIP);

		if ( 'div' == $aqura_args['style'] ) {
			$tag = 'div';
			$add_below = 'comment';
		} else {
			$tag = 'li';
			$add_below = 'div-comment';
		}
		?>
		<<?php echo esc_attr($tag) ?> <?php comment_class( empty( $aqura_args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
		<?php if ( 'div' != $aqura_args['style'] ) : ?>
			<div id="div-comment-<?php comment_ID() ?>" class="comment">
		<?php endif; ?>
		<div class="right-section">
			<h3>
				<?php printf( esc_html__( '%s' , 'aqura' ), get_comment_author_link() ); ?>
			</h3>
			<p class="time-comment">
				<?php
				printf( esc_html__('%1$s','aqura'), get_comment_date('d M Y') ); ?></a><?php edit_comment_link( esc_html__( '(Edit)' , 'aqura' ), '  ', '' );
				?>
				<?php if ( $depth == 1 || $depth == 2 ): ?>
					<span class="slashComment">/</span>
				<?php endif ?>
				<?php comment_reply_link( array_merge( $aqura_args, array( 'add_below' => $add_below , 'reply_text' => esc_html__('Reply ', 'aqura') . '', 'depth' => $depth, 'max_depth' => $aqura_args['max_depth'] ) ) ); ?>
			</p>
			<div class="comment-text">
				<?php comment_text(); ?>
			</div>
		</div>
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'aqura' ); ?></em>
			<br />
		<?php endif; ?>
		<?php if ( 'div' != $aqura_args['style'] ) : ?>
			</div>
		<?php endif; ?>
	<?php }

endif;

if ( !function_exists('aqura_get_article_date_and_author') ) :

	function aqura_get_article_date_and_author($date = true, $author = true) {

		$aqura_output = '';

		if($author) {
			$aqura_output .= esc_html__('Posted by ', 'aqura') . '<a href="'.get_the_permalink().'">' .  get_the_author() . '</a>';
		}

		if($date) {
			$aqura_output .= esc_html__(' on ', 'aqura');
			$aqura_output .=  '<a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">';
			$aqura_output .=	get_the_date();
			$aqura_output .=  '</a>';
		}

		return $aqura_output;
	}

endif;

if ( ! function_exists( 'aqura_get_the_posts_pagination' ) ) {

	function aqura_get_the_posts_pagination() {

		echo '<div class="page-list">';

		$pagination_args = array(
			'base'			=> get_pagenum_link(1) . '%_%',
			'format'		  => 'page/%#%',
			'show_all'		=> False,
			'end_size'		=> 1,
			'prev_next'	   => True,
			'prev_text'	   => '<i class="fa fa-angle-left"></i>',
			'next_text'	   => '<i class="fa fa-angle-right"></i>',
			'type'			=> 'list',
			'add_args'		=> false,
			'add_fragment'	=> ''
		);

		$paginate_links = paginate_links($pagination_args);

		if ($paginate_links) {
			echo balanceTags($paginate_links);
		}
		
		echo '</div>';

	}

}

if( ! function_exists( 'aqura_album_single_nav' ) ) :

	function aqura_album_single_nav($current_id, $post_type) {

		$aqura_args = array(
			'post_type'		 => 'albums',
			'post_status'	   => 'publish',
			// 'posts_per_page'	=> 6,
			'tax_query'		 => ( !empty($cats) ? array(
					array(
						'taxonomy' => 'category',
						'field' => 'id',
						'terms' => $cats
					),
				) : false )
			);

		$posts_array = get_posts( $aqura_args );

		$n = count($posts_array);
		$has_next = false;
		$has_previous = false;
		$next_portfolio = array();
		$previous_portfolio = array();

		for ( $i = 0; $i < $n; $i++ ){
			if ( $current_id == $posts_array[$i]->ID && $n > 1 ) {

				if( $i == 0 ) {
					$has_next = false;
					$has_previous = true;

					$next_portfolio = array();
					$previous_portfolio = array('id' => $posts_array[$i+1]->ID,'author' => $posts_array[$i+1]->post_author,'title' => $posts_array[$i+1]->post_title, 'link' => get_permalink( $posts_array[$i+1]->ID ));
				} else if( $i == $n-1 ) {
					$has_next = true;
					$has_previous = false;

					$next_portfolio = array('id' => $posts_array[$i-1]->ID,'author' => $posts_array[$i-1]->post_author,'title' => $posts_array[$i-1]->post_title, 'link' => get_permalink( $posts_array[$i-1]->ID ));
					$previous_portfolio = array();
				} else {
					$has_next = true;
					$has_previous = true;

					$next_portfolio = array('id' => $posts_array[$i-1]->ID,'author' => $posts_array[$i-1]->post_author,'title' => $posts_array[$i-1]->post_title, 'link' => get_permalink( $posts_array[$i-1]->ID ));
					$previous_portfolio = array('id' => $posts_array[$i+1]->ID,'author' => $posts_array[$i+1]->post_author,'title' => $posts_array[$i+1]->post_title, 'link' => get_permalink( $posts_array[$i+1]->ID ));
				}

			}
		}

		?>

		<div class="section-block  bkg-grey-ultralight pagination-2">
			<div class="row full-width ">
				<?php if ($has_previous) : ?>
				<?php $prev_bg =  wp_get_attachment_image_src(get_post_thumbnail_id($previous_portfolio['id']), 'single-post-thumbnail'); ?>
				<div class="col-sm-6 leftHover" style="background-image: url(<?php echo esc_url($prev_bg[0]); ?>);">
					<a class="pagination-previous" href="<?php echo esc_url($previous_portfolio['link']); ?>">
						<small>
							<?php esc_html_e( 'Prev' , 'aqura' ) ?>
						</small>
						<span>
							<?php echo esc_html($previous_portfolio['title']); ?>
						</span>
					</a>
				</div>
				<?php else: ?>
				<div class="col-sm-6 leftHover"></div>
				<?php endif; ?>
				<?php if ($has_next) : ?>
				<?php $next_bg =  wp_get_attachment_image_src(get_post_thumbnail_id($next_portfolio['id']), 'single-post-thumbnail'); ?>
				<div class="col-sm-6 rightHover" style="background-image: url(<?php echo esc_url($next_bg[0]) ?>);">
					<a class="pagination-next " href="<?php echo esc_url($next_portfolio['link']); ?>">
						<small>
							<?php esc_html_e( 'Next' , 'aqura' ) ?>
						</small>
						<span>
							<?php echo esc_html($next_portfolio['title']); ?>
						</span>
					</a>
				</div>
				<?php else: ?>
				<div class="col-sm-6 rightHover"></div>
				<?php endif; ?>
			</div>
		</div>

	<?php

	}

endif;
