<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }

class VC_Setup {

	protected static $instance = null;


	private function __construct() {

		if (class_exists('Vc_Manager')) {

			/**
			 * Remove other elements.
			 */
			vc_remove_element('vc_posts_grid');

			/**
			 * Setup the new shortcodes.
			 */

			$this->aqura_setup_artist_signature();
			$this->aqura_setup_section_title();
			$this->aqura_setup_full_screen_featured_image_stars();
			$this->aqura_setup_bends_in_town();
			$this->aqura_setup_next_event();
			$this->aqura_setup_articles_news();
			$this->aqura_setup_twitter_feed();
			$this->aqura_setup_gallery_images();
			$this->aqura_setup_full_bg_album();
			$this->aqura_setup_full_video_youtube();
			$this->aqura_setup_full_royal_slider();
			$this->aqura_setup_albums_grid();

		}

	}

	public function aqura_setup_artist_signature() {
		vc_map( array(
			'name' => esc_html__( 'Artist Signature', 'aqura' ),
			'base' => 'artist_signature',
			'category' => esc_html__( 'Aqura Shortcodes', 'aqura' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Artist Name', 'aqura' ),
					'param_name' => 'artist_name'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Artist Link', 'aqura' ),
					'param_name' => 'artist_link'
				),
				array(
					"type" => "attach_image",
					"heading" => esc_html__('Upload a signature', 'aqura'),
					"param_name" => "artist_signature_image"
				)
			)
		) );
	}

	public function aqura_setup_full_screen_featured_image_stars() {
		vc_map( array(
			'name' => esc_html__( 'Full Screen Featured Image With Stars', 'aqura' ),
			'base' => 'full_screen_featured_image_stars',
			'category' => esc_html__( 'Aqura Shortcodes', 'aqura' ),
			'description' => esc_html__( 'Used only at the top of page.', 'aqura' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Small Title 1', 'aqura' ),
					'param_name' => 'small_title_1',
					'value' => 'Theme Brothers'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Big Title', 'aqura' ),
					'param_name' => 'big_title',
					'value' => 'AQURA'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Small Title 2', 'aqura' ),
					'param_name' => 'small_title_2',
					'value' => 'Template'
				),
				array(
					"type" => "attach_image",
					"heading" => esc_html__('Upload an image', 'aqura'),
					"param_name" => "full_screen_featured_image_stars_image"
				)
			)
		) );
	}

	public function aqura_setup_section_title() {
		vc_map( array(
			'name' => esc_html__( 'Section Title', 'aqura' ),
			'base' => 'section_title',
			'category' => esc_html__( 'Aqura Shortcodes', 'aqura' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'aqura' ),
					'param_name' => 'section_text_title',
					'value' => 'The Title'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Link', 'aqura' ),
					'param_name' => 'title_link',
					'value' => '#'
				),
				array(
					"type" => "checkbox",
					"heading" => esc_html__('With Margin Bottom', 'aqura'),
					"param_name" => "margin_bottom_check"
				),
				array(
					"type" => "textarea",
					"heading" => esc_html__('Section Description', 'aqura'),
					"param_name" => "section_description"
				)
			)
		) );
	}

	public function aqura_setup_bends_in_town() {
		vc_map( array(
			"name" => esc_html__( "BandsinTown", 'aqura' ),
			"base" => "bands_in_town",
			"category" => esc_html__( "Aqura Shortcodes", 'aqura'),
			"description" => esc_html__('Shows a fancy BandsInTown tour dates.', 'aqura'),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Artist Name", 'aqura' ),
					"param_name" => "artist",
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Posts per Page", 'aqura' ),
					"param_name" => "posts_per_page",
					"value" => esc_html__( "4", 'aqura' ),
					"description" => esc_html__( "A number. Or it will break your website down.", 'aqura' )
				)
			)
		) );
	}

	public function aqura_setup_next_event() {
		vc_map( array(
			"name" => esc_html__( "Next Event", 'aqura' ),
			"base" => "next_event",
			"category" => esc_html__( "Aqura Shortcodes", 'aqura'),
			"description" => esc_html__('Shows a fancy BandsInTown tour dates.', 'aqura'),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Section Title", 'aqura' ),
					"param_name" => "ne_title",
					"value" => esc_html__( "Next Event", 'aqura' ),
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Event Description", 'aqura' ),
					"param_name" => "ne_description"
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Event Start Date", 'aqura' ),
					"param_name" => "ne_start_date",
					"value" => "2016/10/23",
					"description" => esc_html__( "Year / Month / Day", 'aqura' )
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Event URL", 'aqura' ),
					"param_name" => "ne_url",
					'value' => '#'
				),
				array(
					"type" => "attach_image",
					"heading" => esc_html__( "Event Info Image", 'aqura' ),
					"param_name" => "ne_img"
				)
			)
		) );
	}

	public function aqura_setup_articles_news() {
		vc_map( array(
			"name" => esc_html__( "Articles News", 'aqura' ),
			"base" => "articles_news",
			"category" => esc_html__( "Aqura Shortcodes", 'aqura'),
			"description" => esc_html__('Shows latest posts.', 'aqura'),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Posts Number", 'aqura' ),
					"param_name" => "post_numb",
					"value" => '3',
				)
			)
		) );
	}

	public function aqura_setup_twitter_feed() {
		vc_map( array(
			'name' => esc_html__( 'Twitter Latest', 'aqura' ),
			'base' => 'latest_tweet',
			'category' => esc_html__( 'Aqura Shortcodes', 'aqura' ),
			'description' => esc_html__( 'Twitter feed.', 'aqura' ),
			'params' => array(
				array(
					'type' => 'attach_image',
					'heading' => esc_html__( 'Twitter Account Icon', 'aqura' ),
					'param_name' => 'aqura_twitter_icon',
					'description' => esc_html__( 'Yout twitter avatar. Recomanded size is 48px x 48px.', 'aqura' ),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Username', 'aqura' ),
					'param_name' => 'username',
					'description' => esc_html__( 'Your twitter username.', 'aqura' ),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Twitter URL', 'aqura' ),
					'param_name' => 'aqura_twitter_url',
					'description' => esc_html__( 'The url of your twitter page.', 'aqura' ),
				)
			)
		) );
	}

	public function aqura_setup_gallery_images() {
		vc_map( array(
			"name" => esc_html__( "Gallery Images", 'aqura' ),
			"base" => "gallery_images",
			"category" => esc_html__( "Aqura Shortcodes", 'aqura'),
			"description" => esc_html__('Upload images for gallery.', 'aqura'),
			"params" => array(
				array(
					"type" => "attach_images",
					"heading" => esc_html__( "Gallery Images", 'aqura' ),
					"param_name" => "gallery_images_upload"
				)
			)
		) );
	}

	public function aqura_setup_full_bg_album() {
		vc_map( array(
			'name' => esc_html__( 'Album Full Background', 'aqura' ),
			'base' => 'full_bg_album',
			'category' => esc_html__( 'Aqura Shortcodes', 'aqura' ),
			'description' => esc_html__( 'Full background album.', 'aqura' ),
			'params' => array(
				array(
					'type' => 'attach_image',
					'heading' => esc_html__( 'Album Cover Image', 'aqura' ),
					'param_name' => 'fba_bg',
					'description' => esc_html__( 'Upload a large image for album cover.', 'aqura' ),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'aqura' ),
					'param_name' => 'fba_title',
					'description' => esc_html__( 'Album name.', 'aqura' ),
				),
				array(
					'type' => 'textarea',
					'heading' => esc_html__( 'Description', 'aqura' ),
					'param_name' => 'fba_description',
					'description' => esc_html__( 'Album description.', 'aqura' ),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'iTunes URL', 'aqura' ),
					'param_name' => 'fba_itunes',
					'description' => esc_html__( 'Album iTunes URL.', 'aqura' ),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'SoundCloud URL', 'aqura' ),
					'param_name' => 'fba_sc',
					'description' => esc_html__( 'Album SoundCloud URL.', 'aqura' ),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Album URL', 'aqura' ),
					'param_name' => 'fba_album_url',
					'description' => esc_html__( 'Album URL.', 'aqura' ),
				)
			)
		));
	}

	public function aqura_setup_full_video_youtube() {
		vc_map( array(
			'name' => esc_html__( 'Full Screen Youtube Video', 'aqura' ),
			'base' => 'full_video_youtube',
			'category' => esc_html__( 'Aqura Shortcodes', 'aqura' ),
			'description' => esc_html__( 'Full youtube video.', 'aqura' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Small Title 1', 'aqura' ),
					'param_name' => 'yt_small_title_1',
					'value' => 'Theme Brothers'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Big Title', 'aqura' ),
					'param_name' => 'yt_big_title',
					'value' => 'AQURA'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Small Title 2', 'aqura' ),
					'param_name' => 'yt_small_title_2',
					'value' => 'Template'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Video ID', 'aqura' ),
					'param_name' => 'video_id',
					'description' => esc_html__( 'Youtube video ID.', 'aqura' )
				)
			)
		));
	}

	public function aqura_setup_full_royal_slider() {
		vc_map( array(
			'name' => esc_html__( 'Full Screen Royal Slider', 'aqura' ),
			'base' => 'full_royal_slider',
			'category' => esc_html__( 'Aqura Shortcodes', 'aqura' ),
			'description' => esc_html__( 'Used only at the top of page.', 'aqura' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Small Title 1', 'aqura' ),
					'param_name' => 'small_title_1',
					'value' => 'Theme Brothers'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Big Title', 'aqura' ),
					'param_name' => 'big_title',
					'value' => 'AQURA'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Small Title 2', 'aqura' ),
					'param_name' => 'small_title_2',
					'value' => 'Template'
				),
				array(
					"type" => "attach_images",
					"heading" => esc_html__('Upload images', 'aqura'),
					"param_name" => "slider_images"
				)
			)
		) );
	}

	public function aqura_setup_albums_grid() {
		vc_map( array(
			"name" => esc_html__( "Latest Albums", 'aqura' ),
			"base" => "albums_grid",
			"category" => esc_html__( "Aqura Shortcodes", 'aqura'),
			"description" => esc_html__('Shows latest albums.', 'aqura'),
			"params" => array(
				array(
					"type" => "textfield",
					"heading" => esc_html__( "Albums Number", 'aqura' ),
					"param_name" => "albums_numb",
					"value" => '4',
				)
			)
		) );
	}

	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

}

VC_Setup::get_instance();

