<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you (the theme developer).
 * will need to copy the new files to your theme to maintain compatibility. We try to do this.
 * as little as possible, but it does happen. When this occurs the version of the template file will.
 * be bumped and the readme will list any important changes.
 *
 * @see 	    http://docs.woothemes.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$page_id = get_option( 'woocommerce_shop_page_id' );
$aqura_args = array();

$aqura_title = rwmb_meta( 'aqura_single_article_title', $aqura_args, $page_id );
$aqura_small_description = rwmb_meta( 'aqura_small_description', $aqura_args, $page_id );

$aqura_feat_image = wp_get_attachment_url( get_post_thumbnail_id($post->ID));

if( is_shop() ) {

	$aqura_feat_image = wp_get_attachment_url( get_post_thumbnail_id($page_id));

}

get_header(); ?>

	<!-- =============== START BREADCRUMB ================ -->
	<section class="no-mb">
		<div class="row">
			<div class="col-sm-12">
				<div class="breadcrumb-fullscreen-parent phone-menu-bg">
					<div class="breadcrumb breadcrumb-fullscreen alignleft small-description overlay almost-black-overlay" style="background-image: url(<?php echo esc_url($aqura_feat_image); ?>);" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
						<div class="breadTxt">
							<h1>
								<?php if ( $aqura_title != '' ): ?>
									<?php echo esc_html($aqura_title); ?>
								<?php else: ?>
									<?php echo esc_html(get_the_title()); ?>
								<?php endif ?>
							</h1>
							<p>
								<?php echo balanceTags($aqura_small_description); ?>
							</p>
							<a href="#content" data-easing="easeInOutQuint" data-scroll="" data-speed="900" data-url="false">
								<?php esc_html_e( 'View More' , 'aqura') ?> <i class="fa fa-angle-down"></i>
							</a>
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<div id="content"></div>
	<!-- =============== END BREADCRUMB ================ -->

	<!-- ================================================== -->
	<!-- =============== START CONTENT PAGE ================ -->
	<!-- ================================================== -->

	<?php if ( have_posts() ) : ?>

		<nav class="shop-products row">
		<ul class="products columns-3">

			<?php woocommerce_product_subcategories(); ?>

			<?php while( have_posts() ) : the_post(); ?>

				<?php wc_get_template_part( 'content', 'product' ); ?>

			<?php endwhile; // end of the loop. ?>

		</ul>
		</nav>

	<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

		<?php wc_get_template( 'loop/no-products-found.php' ); ?>

	<?php endif; ?>

<?php get_footer( 'shop' ); ?>